@@ -42,6 +42,9 @@ class BaseDataModel(object):
             return self.to_dict() == other.to_dict()
         return False
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     @classmethod
     def from_dict(cls, dict):
         return cls(**dict)
@@ -64,7 +67,7 @@ class BaseDataModel(object):
         elif obj.__class__.__name__ in ['SessionPersistence', 'HealthMonitor']:
             return obj.__class__.__name__ + obj.pool_id
         elif obj.__class__.__name__ in ['ListenerStatistics']:
-            return obj.__class__.__name__ + obj.listener_id
+            return obj.__class__.__name__ + obj.listener_id + obj.amphora_id
         elif obj.__class__.__name__ in ['VRRPGroup', 'Vip']:
             return obj.__class__.__name__ + obj.load_balancer_id
         elif obj.__class__.__name__ in ['AmphoraHealth']:
@@ -132,18 +135,15 @@ class SessionPersistence(BaseDataModel):
 
 class ListenerStatistics(BaseDataModel):
 
-    def __init__(self, listener_id=None, bytes_in=None, bytes_out=None,
-                 active_connections=None, total_connections=None,
-                 listener=None):
+    def __init__(self, listener_id=None, amphora_id=None, bytes_in=None,
+                 bytes_out=None, active_connections=None,
+                 total_connections=None):
         self.listener_id = listener_id
+        self.amphora_id = amphora_id
         self.bytes_in = bytes_in
         self.bytes_out = bytes_out
         self.active_connections = active_connections
         self.total_connections = total_connections
-        self.listener = listener
-
-    def delete(self):
-        self.listener.stats = None
 
 
 class HealthMonitor(BaseDataModel):
@@ -151,7 +151,8 @@ class HealthMonitor(BaseDataModel):
     def __init__(self, id=None, project_id=None, pool_id=None, type=None,
                  delay=None, timeout=None, fall_threshold=None,
                  rise_threshold=None, http_method=None, url_path=None,
-                 expected_codes=None, enabled=None, pool=None):
+                 expected_codes=None, enabled=None, pool=None,
+                 provisioning_status=None):
         self.id = id
         self.project_id = project_id
         self.pool_id = pool_id
@@ -165,18 +166,19 @@ class HealthMonitor(BaseDataModel):
         self.expected_codes = expected_codes
         self.enabled = enabled
         self.pool = pool
+        self.provisioning_status = provisioning_status
 
     def delete(self):
         self.pool.health_monitor = None
 
 
 class Pool(BaseDataModel):
-
     def __init__(self, id=None, project_id=None, name=None, description=None,
                  protocol=None, lb_algorithm=None, enabled=None,
                  operating_status=None, members=None, health_monitor=None,
                  session_persistence=None, load_balancer_id=None,
-                 load_balancer=None, listeners=None, l7policies=None):
+                 load_balancer=None, listeners=None, l7policies=None,
+                 created_at=None, updated_at=None, provisioning_status=None):
         self.id = id
         self.project_id = project_id
         self.name = name
@@ -192,6 +194,9 @@ class Pool(BaseDataModel):
         self.session_persistence = session_persistence
         self.listeners = listeners or []
         self.l7policies = l7policies or []
+        self.created_at = created_at
+        self.updated_at = updated_at
+        self.provisioning_status = provisioning_status
 
     def update(self, update_dict):
         for key, value in update_dict.items():
@@ -235,7 +240,8 @@ class Member(BaseDataModel):
 
     def __init__(self, id=None, project_id=None, pool_id=None, ip_address=None,
                  protocol_port=None, weight=None, enabled=None,
-                 subnet_id=None, operating_status=None, pool=None):
+                 subnet_id=None, operating_status=None, pool=None,
+                 created_at=None, updated_at=None, provisioning_status=None):
         self.id = id
         self.project_id = project_id
         self.pool_id = pool_id
@@ -246,6 +252,9 @@ class Member(BaseDataModel):
         self.subnet_id = subnet_id
         self.operating_status = operating_status
         self.pool = pool
+        self.created_at = created_at
+        self.updated_at = updated_at
+        self.provisioning_status = provisioning_status
 
     def delete(self):
         for mem in self.pool.members:
@@ -262,7 +271,8 @@ class Listener(BaseDataModel):
                  enabled=None, provisioning_status=None, operating_status=None,
                  tls_certificate_id=None, stats=None, default_pool=None,
                  load_balancer=None, sni_containers=None, peer_port=None,
-                 l7policies=None, pools=None):
+                 l7policies=None, pools=None, insert_headers=None,
+                 created_at=None, updated_at=None):
         self.id = id
         self.project_id = project_id
         self.name = name
@@ -282,7 +292,10 @@ class Listener(BaseDataModel):
         self.sni_containers = sni_containers or []
         self.peer_port = peer_port
         self.l7policies = l7policies or []
+        self.insert_headers = insert_headers or {}
         self.pools = pools or []
+        self.created_at = created_at
+        self.updated_at = updated_at
 
     def update(self, update_dict):
         for key, value in update_dict.items():
@@ -320,7 +333,8 @@ class LoadBalancer(BaseDataModel):
     def __init__(self, id=None, project_id=None, name=None, description=None,
                  provisioning_status=None, operating_status=None, enabled=None,
                  topology=None, vip=None, listeners=None, amphorae=None,
-                 pools=None, vrrp_group=None, server_group_id=None):
+                 pools=None, vrrp_group=None, server_group_id=None,
+                 created_at=None, updated_at=None):
 
         self.id = id
         self.project_id = project_id
@@ -336,6 +350,8 @@ class LoadBalancer(BaseDataModel):
         self.amphorae = amphorae or []
         self.pools = pools or []
         self.server_group_id = server_group_id
+        self.created_at = created_at
+        self.updated_at = updated_at
 
 
 class VRRPGroup(BaseDataModel):
@@ -429,7 +445,7 @@ class L7Rule(BaseDataModel):
 
     def __init__(self, id=None, l7policy_id=None, type=None,
                  compare_type=None, key=None, value=None, l7policy=None,
-                 invert=False):
+                 invert=False, provisioning_status=None):
         self.id = id
         self.l7policy_id = l7policy_id
         self.type = type
@@ -438,6 +454,7 @@ class L7Rule(BaseDataModel):
         self.value = value
         self.l7policy = l7policy
         self.invert = invert
+        self.provisioning_status = provisioning_status
 
     def delete(self):
         if len(self.l7policy.l7rules) == 1:
@@ -456,7 +473,7 @@ class L7Policy(BaseDataModel):
     def __init__(self, id=None, name=None, description=None, listener_id=None,
                  action=None, redirect_pool_id=None, redirect_url=None,
                  position=None, listener=None, redirect_pool=None,
-                 enabled=None, l7rules=None):
+                 enabled=None, l7rules=None, provisioning_status=None):
         self.id = id
         self.name = name
         self.description = description
@@ -469,6 +486,7 @@ class L7Policy(BaseDataModel):
         self.redirect_pool = redirect_pool
         self.enabled = enabled
         self.l7rules = l7rules or []
+        self.provisioning_status = provisioning_status
 
     def _conditionally_remove_pool_links(self, pool):
         """Removes links to the given pool from parent objects.
