@@ -80,6 +80,11 @@ class InvalidOption(APIException):
     code = 400
 
 
+class L7RuleValidation(APIException):
+    msg = _("Error parsing L7Rule: %(error)s")
+    code = 400
+
+
 class InvalidHMACException(OctaviaException):
     message = _("HMAC hashes didn't match")
 
@@ -135,25 +140,39 @@ class DuplicatePoolEntry(APIException):
     code = 409
 
 
+class PoolInUseByL7Policy(APIException):
+    msg = _("Pool %(id)s is in use by L7 policy %(l7policy_id)s")
+    code = 409
+
+
 class ImmutableObject(APIException):
     msg = _("%(resource)s %(id)s is immutable and cannot be updated.")
     code = 409
 
 
+class TooManyL7RulesOnL7Policy(APIException):
+    message = _("Too many rules on L7 policy %(id)s")
+    code = 409
+
+
 class ComputeBuildException(OctaviaException):
-    message = _LE('Failed to build nova instance.')
+    message = _LE('Failed to build compute instance.')
 
 
 class ComputeDeleteException(OctaviaException):
-    message = _LE('Failed to delete nova instance.')
+    message = _LE('Failed to delete compute instance.')
 
 
 class ComputeGetException(OctaviaException):
-    message = _LE('Failed to retrieve nova instance.')
+    message = _LE('Failed to retrieve compute instance.')
 
 
 class ComputeStatusException(OctaviaException):
-    message = _LE('Failed to retrieve nova instance status.')
+    message = _LE('Failed to retrieve compute instance status.')
+
+
+class ComputeGetInterfaceException(OctaviaException):
+    message = _LE('Failed to retrieve compute virtual interfaces.')
 
 
 class IDAlreadyExists(OctaviaException):
@@ -165,13 +184,56 @@ class NoReadyAmphoraeException(OctaviaException):
     message = _LE('There are not any READY amphora available.')
 
 
+class GlanceNoTaggedImages(OctaviaException):
+    message = _LE("No Glance images are tagged with %(tag)s tag.")
+
+
 class NoSuitableAmphoraException(OctaviaException):
     message = _LE('Unable to allocate an amphora due to: %(msg)s')
 
 
 # This is an internal use exception for the taskflow work flow
 # and will not be exposed to the customer.  This means it is a
-# normal part of operation while waiting for nova to go active
+# normal part of operation while waiting for compute to go active
 # on the instance
 class ComputeWaitTimeoutException(OctaviaException):
     message = _LI('Waiting for compute to go active timeout.')
+
+
+class InvalidTopology(OctaviaException):
+    message = _LE('Invalid topology specified: %(topology)s')
+
+
+# L7 policy and rule exceptions
+class InvalidL7PolicyAction(APIException):
+    message = _LE('Invalid L7 Policy action specified: %(action)s')
+    code = 400
+
+
+class InvalidL7PolicyArgs(APIException):
+    message = _LE('Invalid L7 Policy arguments: %(msg)s')
+    code = 400
+
+
+class InvalidURL(OctaviaException):
+    message = _LE('Not a valid URL: %(url)s')
+
+
+class InvalidString(OctaviaException):
+    message = _LE('Invalid characters in %(what)s')
+
+
+class InvalidRegex(OctaviaException):
+    message = _LE('Unable to parse regular expression: %(e)s')
+
+
+class InvalidL7Rule(OctaviaException):
+    message = _LE('Invalid L7 Rule: $(msg)s')
+
+
+class ServerGroupObjectCreateException(OctaviaException):
+    message = _LE('Failed to create server group object.')
+
+
+class ServerGroupObjectDeleteException(OctaviaException):
+    message = _LE('Failed to delete server group object.')
