@@ -14,9 +14,11 @@
 
 import copy
 
+import mock
 from oslo_utils import uuidutils
 
 from octavia.common import constants
+from octavia.network import base as network_base
 from octavia.tests.functional.api.v1 import base
 
 
@@ -39,6 +41,8 @@ class TestLoadBalancer(base.BaseAPITest):
         self.assertEqual(constants.OFFLINE,
                          api_lb.get('operating_status'))
         self.assertTrue(api_lb.get('enabled'))
+        self.assertIsNotNone(api_lb.get('created_at'))
+        self.assertIsNone(api_lb.get('updated_at'))
         for key, value in optionals.items():
             self.assertEqual(value, lb_json.get(key))
         self.assert_final_lb_statuses(api_lb.get('id'))
@@ -154,6 +158,8 @@ class TestLoadBalancer(base.BaseAPITest):
                          api_lb.get('provisioning_status'))
         self.assertEqual(lb.get('operational_status'),
                          api_lb.get('operational_status'))
+        self.assertIsNotNone(api_lb.get('created_at'))
+        self.assertIsNotNone(api_lb.get('updated_at'))
         self.assert_final_lb_statuses(api_lb.get('id'))
 
     def test_update_with_vip(self):
@@ -194,6 +200,12 @@ class TestLoadBalancer(base.BaseAPITest):
         self.put(self.LB_PATH.format(lb_id=lb.get('id')), lb_json)
         self.delete(self.LB_PATH.format(lb_id=lb.get('id')), status=409)
 
+    def test_delete_with_error_status(self):
+        lb = self.create_load_balancer({}, name='lb1', description='desc1',
+                                       enabled=False)
+        lb = self.set_lb_status(lb.get('id'), status=constants.ERROR)
+        self.delete(self.LB_PATH.format(lb_id=lb.get('id')), status=202)
+
     def test_update_pending_delete(self):
         lb = self.create_load_balancer({}, name='lb1', description='desc1',
                                        enabled=False)
@@ -229,6 +241,32 @@ class TestLoadBalancer(base.BaseAPITest):
         path = self.LB_PATH.format(lb_id='bad_uuid')
         self.delete(path, status=404)
 
+    def test_create_with_bad_subnet(self, **optionals):
+        with mock.patch(
+                'octavia.common.utils.get_network_driver') as net_mock:
+            net_mock.return_value.get_subnet = mock.Mock(
+                side_effect=network_base.SubnetNotFound('Subnet not found'))
+            subnet_id = uuidutils.generate_uuid()
+            lb_json = {'name': 'test1', 'vip': {'subnet_id': subnet_id,
+                                                'ip_address': '10.0.0.1'}}
+            lb_json.update(optionals)
+            response = self.post(self.LBS_PATH, lb_json, expect_errors=True)
+            err_msg = 'Subnet ' + subnet_id + ' not found.'
+            self.assertEqual(response.json.get('faultstring'), err_msg)
+
+    def test_create_with_valid_subnet(self, **optionals):
+        subnet_id = uuidutils.generate_uuid()
+        with mock.patch(
+                'octavia.common.utils.get_network_driver') as net_mock:
+            net_mock.return_value.get_subnet.return_value = subnet_id
+            lb_json = {'name': 'test1', 'vip': {'subnet_id': subnet_id,
+                                                'ip_address': '10.0.0.1'}}
+            lb_json.update(optionals)
+            response = self.post(self.LBS_PATH, lb_json)
+            api_lb = response.json
+            self.assertEqual(lb_json.get('vip')['subnet_id'],
+                             api_lb.get('vip')['subnet_id'])
+
 
 class TestLoadBalancerGraph(base.BaseAPITest):
 
@@ -238,12 +276,18 @@ class TestLoadBalancerGraph(base.BaseAPITest):
 
     def _assert_graphs_equal(self, expected_graph, observed_graph):
         observed_graph_copy = copy.deepcopy(observed_graph)
+        del observed_graph_copy['created_at']
+        del observed_graph_copy['updated_at']
         obs_lb_id = observed_graph_copy.pop('id')
+
         self.assertTrue(uuidutils.is_uuid_like(obs_lb_id))
         expected_listeners = expected_graph.pop('listeners', [])
         observed_listeners = observed_graph_copy.pop('listeners', [])
         self.assertEqual(expected_graph, observed_graph_copy)
         for observed_listener in observed_listeners:
+            del observed_listener['created_at']
+            del observed_listener['updated_at']
+
             self.assertTrue(uuidutils.is_uuid_like(
                 observed_listener.pop('id')))
             default_pool = observed_listener.get('default_pool')
@@ -251,6 +295,8 @@ class TestLoadBalancerGraph(base.BaseAPITest):
                 observed_listener.pop('default_pool_id')
                 self.assertTrue(default_pool.get('id'))
                 default_pool.pop('id')
+                default_pool.pop('created_at')
+                default_pool.pop('updated_at')
                 hm = default_pool.get('healthmonitor')
                 if hm:
                     self.assertTrue(hm.get('id'))
@@ -258,6 +304,8 @@ class TestLoadBalancerGraph(base.BaseAPITest):
                 for member in default_pool.get('members', []):
                     self.assertTrue(member.get('id'))
                     member.pop('id')
+                    member.pop('created_at')
+                    member.pop('updated_at')
             if observed_listener.get('sni_containers'):
                 observed_listener['sni_containers'].sort()
             o_l7policies = observed_listener.get('l7policies')
@@ -267,12 +315,16 @@ class TestLoadBalancerGraph(base.BaseAPITest):
                         r_pool = o_l7policy.get('redirect_pool')
                         self.assertTrue(r_pool.get('id'))
                         r_pool.pop('id')
+                        r_pool.pop('created_at')
+                        r_pool.pop('updated_at')
                         self.assertTrue(o_l7policy.get('redirect_pool_id'))
                         o_l7policy.pop('redirect_pool_id')
                         if r_pool.get('members'):
                             for r_member in r_pool.get('members'):
                                 self.assertTrue(r_member.get('id'))
                                 r_member.pop('id')
+                                r_member.pop('created_at')
+                                r_member.pop('updated_at')
                     self.assertTrue(o_l7policy.get('id'))
                     o_l7policy.pop('id')
                     l7rules = o_l7policy.get('l7rules')
@@ -320,7 +372,8 @@ class TestLoadBalancerGraph(base.BaseAPITest):
             'connection_limit': None,
             'enabled': True,
             'provisioning_status': constants.PENDING_CREATE,
-            'operating_status': constants.OFFLINE
+            'operating_status': constants.OFFLINE,
+            'insert_headers': {}
         }
         if create_sni_containers:
             create_listener['sni_containers'] = create_sni_containers
@@ -678,3 +731,14 @@ class TestLoadBalancerGraph(base.BaseAPITest):
         response = self.post(self.LBS_PATH, create_lb)
         api_lb = response.json
         self._assert_graphs_equal(expected_lb, api_lb)
+
+    def test_db_create_failure(self):
+        create_listener, expected_listener = self._get_listener_bodies()
+        create_lb, _ = self._get_lb_bodies([create_listener],
+                                           [expected_listener])
+        # with mock.patch('octavia.db.repositories.Repositories') as repo_mock:
+        with mock.patch('octavia.db.repositories.Repositories.'
+                        'create_load_balancer_tree') as repo_mock:
+            repo_mock.side_effect = Exception('I am a DB Error')
+            response = self.post(self.LBS_PATH, create_lb, expect_errors=True)
+            self.assertEqual(500, response.status_code)
