@@ -33,11 +33,11 @@ from tempest import config
 from tempest import exceptions
 from tempest.lib.common.utils import test_utils
 from tempest.lib import exceptions as lib_exc
-from tempest.scenario import manager
 from tempest import test
 
 
 from octavia.i18n import _
+from octavia.tests.tempest.common import manager
 from octavia.tests.tempest.v1.clients import health_monitors_client
 from octavia.tests.tempest.v1.clients import listeners_client
 from octavia.tests.tempest.v1.clients import load_balancers_client
@@ -65,9 +65,6 @@ class BaseTestCase(manager.NetworkScenarioTest):
         self.server_ips = {}
         self.server_fixed_ips = {}
 
-        self._create_security_group_for_test()
-        self._set_net_and_subnet()
-
         mgr = self.get_client_manager()
 
         auth_provider = mgr.auth_provider
@@ -84,6 +81,10 @@ class BaseTestCase(manager.NetworkScenarioTest):
             health_monitors_client.HealthMonitorsClient(
                 *self.client_args))
 
+        self.tenant_id = self.load_balancers_client.tenant_id
+        self._create_security_group_for_test()
+        self._set_net_and_subnet()
+
         # admin network client needed for assigning octavia port to flip
         admin_manager = credentials_factory.AdminManager()
         admin_manager.auth_provider.fill_credentials()
@@ -111,12 +112,14 @@ class BaseTestCase(manager.NetworkScenarioTest):
         fallback in absence of tenant networking.
         """
         try:
-            tenant_net = self._list_networks(tenant_id=self.tenant_id)[0]
+            tenant_net = self.admin_manager.networks_client.list_networks(
+                tenant_id=self.tenant_id)['networks'][0]
         except IndexError:
             tenant_net = None
 
         if tenant_net:
-            tenant_subnet = self._list_subnets(tenant_id=self.tenant_id)[0]
+            tenant_subnet = self.admin_manager.subnets_client.list_subnets(
+                tenant_id=self.tenant_id)['subnets'][0]
             self.subnet = tenant_subnet
             self.network = tenant_net
         else:
@@ -126,7 +129,8 @@ class BaseTestCase(manager.NetworkScenarioTest):
             # with the fixed network is the one we want.  In the future, we
             # should instead pull a subnet id from config, which is set by
             # devstack/admin/etc.
-            subnet = self._list_subnets(network_id=self.network['id'])[0]
+            subnet = self.admin_manager.subnets_client.list_subnets(
+                network_id=self.network['id'])['subnets'][0]
             self.subnet = subnet
 
     def _create_security_group_for_test(self):
